package bzr4idea.util;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.project.ProjectManager;
import com.intellij.openapi.vcs.AbstractVcs;
import com.intellij.openapi.vcs.ProjectLevelVcsManager;
import com.intellij.openapi.vcs.FilePath;
import com.intellij.openapi.vcs.vfs.VcsFileSystem;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.openapi.vfs.VfsUtil;
import com.intellij.openapi.vfs.VirtualFileSystem;
import com.intellij.openapi.vfs.LocalFileSystem;
import com.intellij.util.io.fs.FileSystem;
import com.intellij.vcsUtil.VcsUtil;
import git4idea.GitVcs;

import java.util.List;
import java.util.ArrayList;
import java.util.Collection;
import java.io.File;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * @author Patrik Beno
 */
public class IdeaHelper {

  static public GitVcs getVCS(VirtualFile file) {
    Project[] projects = ProjectManager.getInstance().getOpenProjects();
    for (Project project : projects) {
      AbstractVcs vcs = ProjectLevelVcsManager.getInstance(project).getVcsFor(file);
      if (vcs instanceof GitVcs) {
        return (GitVcs)vcs;
      }
    }
    return null;
  }

  static public List<File> toFiles(Collection<FilePath> filepaths) {
    List<File> files = new ArrayList<File>();
    for (FilePath fp : filepaths) {
      files.add(fp.getIOFile());
    }
    return files;
  }

  static public File[] toFileArray(Collection<FilePath> filepaths) {
    return toFiles(filepaths).toArray(new File[filepaths.size()]);
  }

  static public List<FilePath> toFilePaths(List<VirtualFile> vfiles) {
    List<FilePath> files = new ArrayList<FilePath>();
    for (VirtualFile vf : vfiles) {
      files.add(VcsUtil.getFilePath(vf.getPath()));
    }
    return files;
  }

  static public File getIOFile(VirtualFile vf) {
    return new File(vf.getPath()).getAbsoluteFile();
  }

  static public FilePath getFilePath(VirtualFile vf) {
    return VcsUtil.getFilePath(getIOFile(vf));
  }

  static public <T> int addAll( @NotNull Collection<T> dst, @Nullable Collection<T> src )
  {
    if ( src == null ) return 0;
    dst.addAll( src );
    return src.size();
  }
}
