package git4idea.history;
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 * the specific language governing permissions and limitations under the License.
 *
 * Copyright 2007 Decentrix Inc
 * Copyright 2007 Aspiro AS
 * Copyright 2008 MQSoftware
 * Copyright 2008 JetBrains s.r.o.
 * Authors: gevession, Erlend Simonsen & Mark Scott
 *
 * This code was originally derived from the MKS & Mercurial IDEA VCS plugins
 */

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.diagnostic.Logger;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vcs.FilePath;
import com.intellij.openapi.vcs.VcsException;
import com.intellij.openapi.vcs.history.*;
import com.intellij.util.ui.ColumnInfo;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;

/**
 * Git history provider implementation
 */
public class BzrHistoryProvider implements VcsHistoryProvider {
  /**
   * logger instance
   */
  private static final Logger log = Logger.getInstance(BzrHistoryProvider.class.getName());
  /**
   * the current project instance
   */
  private final Project project;

  
  /**
   * A constructor
   *
   * @param project a context project
   */
  public BzrHistoryProvider(@NotNull Project project) {
    this.project = project;
  }

  /**
   * {@inheritDoc}
   */
  public ColumnInfo[] getRevisionColumns(final VcsHistorySession session) {
    return new ColumnInfo[0];
  }

  /**
   * {@inheritDoc}
   */
  public AnAction[] getAdditionalActions(FileHistoryPanel panel) {
    return new AnAction[0];
  }

  /**
   * {@inheritDoc}
   */
  public boolean isDateOmittable() {
    return false;
  }

  /**
   * {@inheritDoc}
   */
  @Nullable
  public String getHelpId() {
    return null;
  }

  /**
   * {@inheritDoc}
   */
  @Nullable
  public VcsHistorySession createSessionFor(final FilePath filePath) throws VcsException {
    /* git4idea
    if (filePath.isDirectory()) {
      return null;
    }
    */
    List<VcsFileRevision> revisions = GitHistoryUtils.history(project, filePath);
    return new VcsHistorySession(revisions) {
      @Nullable
      protected VcsRevisionNumber calcCurrentRevisionNumber() {
        try {
          /* git4idea
          return GitHistoryUtils.getCurrentRevision(project, GitHistoryUtils.getLastCommitName(project, filePath));
          */
          return GitHistoryUtils.getCurrentRevision(project, filePath);
        }
        catch (VcsException e) {
          // likely the file is not under VCS anymore.
          if (log.isDebugEnabled()) {
            log.debug("Unable to retrieve the current revision number", e);
          }
          return null;
        }
      }
    };
  }

  /**
   * {@inheritDoc}
   */
  @Nullable
  public HistoryAsTreeProvider getTreeHistoryProvider() {
    return new GitHistoryTreeProvider();
  }

  /**
   * {@inheritDoc}
   */
  public boolean supportsHistoryForDirectories() {
    /* git4idea
    return false;
    */
    return true;
  }
}
